//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by rufus.rc
//
#define IDD_DIALOG                      101
#define IDD_ABOUTBOX                    102
#define IDD_NOTIFICATION                103
#define IDD_SELECTION                   104
#define IDD_LICENSE                     105
#define IDD_LOG                         106
#define IDD_UPDATE_POLICY               107
#define IDD_NEW_VERSION                 108
#define IDD_HASH                        109
#define IDD_LIST                        110
#define IDI_ICON                        120
#define IDI_LANG_16                     121
#define IDI_INFO_16                     122
#define IDI_SETTINGS_16                 123
#define IDI_LOG_16                      124
#define IDI_SAVE_16                     125
#define IDI_HASH_16                     126
#define IDI_LANG_24                     131
#define IDI_INFO_24                     132
#define IDI_SETTINGS_24                 133
#define IDI_LOG_24                      134
#define IDI_SAVE_24                     135
#define IDI_HASH_24                     136
#define IDI_LANG_32                     141
#define IDI_INFO_32                     142
#define IDI_SETTINGS_32                 143
#define IDI_LOG_32                      144
#define IDI_SAVE_32                     145
#define IDI_HASH_32                     146
#define IDR_FD_COMMAND_COM              300
#define IDR_FD_KERNEL_SYS               301
#define IDR_FD_DISPLAY_EXE              302
#define IDR_FD_KEYB_EXE                 303
#define IDR_FD_MODE_COM                 304
#define IDR_FD_KB1_SYS                  305
#define IDR_FD_KB2_SYS                  306
#define IDR_FD_KB3_SYS                  307
#define IDR_FD_KB4_SYS                  308
#define IDR_FD_EGA1_CPX                 309
#define IDR_FD_EGA2_CPX                 310
#define IDR_FD_EGA3_CPX                 311
#define IDR_FD_EGA4_CPX                 312
#define IDR_FD_EGA5_CPX                 313
#define IDR_FD_EGA6_CPX                 314
#define IDR_FD_EGA7_CPX                 315
#define IDR_FD_EGA8_CPX                 316
#define IDR_FD_EGA9_CPX                 317
#define IDR_FD_EGA10_CPX                318
#define IDR_FD_EGA11_CPX                319
#define IDR_FD_EGA12_CPX                320
#define IDR_FD_EGA13_CPX                321
#define IDR_FD_EGA14_CPX                322
#define IDR_FD_EGA15_CPX                323
#define IDR_FD_EGA16_CPX                324
#define IDR_FD_EGA17_CPX                325
#define IDR_FD_EGA18_CPX                326
#define IDR_SL_LDLINUX_V4_BSS           400
#define IDR_SL_LDLINUX_V4_SYS           401
#define IDR_SL_LDLINUX_V6_BSS           402
#define IDR_SL_LDLINUX_V6_SYS           403
#define IDR_SL_MBOOT_C32                404
#define IDR_GR_GRUB_GRLDR_MBR           450
#define IDR_GR_GRUB2_CORE_IMG           451
#define IDR_SBR_MSG                     452
#define IDR_LC_RUFUS_LOC                500
#define IDR_XT_HOGGER                   501
#define IDR_UEFI_NTFS                   502
#define IDR_SETUP_X64                   503
#define IDR_SETUP_ARM64                 504
// The following should match the ArchType array values + 600
#define IDR_MD5_BOOT                    600
#define IDR_MD5_BOOTIA32                601
#define IDR_MD5_BOOTX64                 602
#define IDR_MD5_BOOTARM                 603
#define IDR_MD5_BOOTAA64                604
#define IDR_MD5_BOOTRISCV64             607
#define IDM_SELECT                      901
#define IDM_DOWNLOAD                    902
#define IDC_DEVICE                      1001
#define IDC_FILE_SYSTEM                 1002
#define IDC_START                       1003
#define IDC_PARTITION_TYPE              1004
#define IDC_CLUSTER_SIZE                1005
#define IDC_STATUS                      1006
#define IDC_LABEL                       1007
#define IDC_QUICK_FORMAT                1008
#define IDC_BAD_BLOCKS                  1009
#define IDC_PROGRESS                    1010
#define IDC_BOOT_SELECTION              1011
#define IDC_NB_PASSES                   1012
#define IDC_TEST                        1013
#define IDC_SELECT                      1014
#define IDC_EXTENDED_LABEL              1015
#define IDC_TARGET_SYSTEM               1017
#define IDC_PERSISTENCE_SIZE            1018
#define IDC_PERSISTENCE_UNITS           1019
#define IDC_OLD_BIOS_FIXES              1020
#define IDC_UEFI_MEDIA_VALIDATION       1021
#define IDC_LIST_USB_HDD                1022
#define IDC_STATUS_TOOLBAR              1023
#define IDC_SAVE                        1024
#define IDC_HASH                        1025
#define IDC_IMAGE_OPTION                1026
#define IDC_PERSISTENCE_SLIDER          1027
#define IDC_ADVANCED_DRIVE_PROPERTIES   1028
#define IDC_ADVANCED_FORMAT_OPTIONS     1029
#define IDC_ABOUT_LICENSE               1030
#define IDC_ABOUT_ICON                  1031
#define IDC_ABOUT_COPYRIGHTS            1032
#define IDC_ABOUT_BLURB                 1033
#define IDC_LICENSE_TEXT                1034
#define IDC_NOTIFICATION_ICON           1040
#define IDC_NOTIFICATION_TEXT           1041
#define IDC_NOTIFICATION_LINE           1042
#define IDC_ADVANCED_DEVICE_TOOLBAR     1043
#define IDC_ADVANCED_FORMAT_TOOLBAR     1044
#define IDC_SAVE_TOOLBAR                1045
#define IDC_HASH_TOOLBAR                1046
#define IDC_MULTI_TOOLBAR               1047
#define IDC_LANG                        1051
#define IDC_ABOUT                       1052
#define IDC_SETTINGS                    1053
#define IDC_LOG                         1054
#define IDC_LOG_EDIT                    1055
#define IDC_LOG_SAVE                    1056
#define IDC_LOG_CLEAR                   1057
#define IDC_DONT_DISPLAY_AGAIN          1059
#define IDC_MORE_INFO                   1060
#define IDC_POLICY                      1061
#define IDC_UPDATE_FREQUENCY            1062
#define IDC_INCLUDE_BETAS               1063
#define IDC_RELEASE_NOTES               1064
#define IDC_DOWNLOAD                    1065
#define IDC_CHECK_NOW                   1066
#define IDC_WEBSITE                     1067
#define IDC_YOUR_VERSION                1068
#define IDC_LATEST_VERSION              1069
#define IDC_DOWNLOAD_URL                1070
#define IDC_MD5                         1071
#define IDC_SHA1                        1072
#define IDC_SHA256                      1073
#define IDC_SHA512                      1074
#define IDC_SELECTION_ICON              1075
#define IDC_SELECTION_TEXT              1076
#define IDC_SELECTION_LINE              1077
#define IDC_SELECTION_CHOICE1           1078
#define IDC_SELECTION_CHOICE2           1079
#define IDC_SELECTION_CHOICE3           1080
#define IDC_SELECTION_CHOICE4           1081
#define IDC_SELECTION_CHOICE5           1082
#define IDC_SELECTION_CHOICE6           1083
#define IDC_SELECTION_CHOICE7           1084
#define IDC_SELECTION_CHOICE8           1085
#define IDC_SELECTION_CHOICE9           1086
#define IDC_SELECTION_CHOICE10          1087
#define IDC_SELECTION_CHOICE11          1088
#define IDC_SELECTION_CHOICE12          1089
#define IDC_SELECTION_CHOICE13          1090
#define IDC_SELECTION_CHOICE14          1091
#define IDC_SELECTION_CHOICE15          1092
#define IDC_SELECTION_CHOICEMAX         1093
#define IDC_SELECTION_USERNAME          1094
#define IDC_LIST_ICON                   1095
#define IDC_LIST_TEXT                   1096
#define IDC_LIST_LINE                   1097
#define IDC_LIST_ITEM1                  1098
#define IDC_LIST_ITEM2                  1099
#define IDC_LIST_ITEM3                  1100
#define IDC_LIST_ITEM4                  1101
#define IDC_LIST_ITEM5                  1102
#define IDC_LIST_ITEM6                  1103
#define IDC_LIST_ITEM7                  1104
#define IDC_LIST_ITEM8                  1105
#define IDC_LIST_ITEM9                  1106
#define IDC_LIST_ITEM10                 1107
#define IDC_LIST_ITEM11                 1108
#define IDC_LIST_ITEM12                 1109
#define IDC_LIST_ITEM13                 1110
#define IDC_LIST_ITEM14                 1111
#define IDC_LIST_ITEM15                 1112
#define IDC_LIST_ITEMMAX                1113
#define IDS_DEVICE_TXT                  2000
#define IDS_PARTITION_TYPE_TXT          2001
#define IDS_FILE_SYSTEM_TXT             2002
#define IDS_CLUSTER_SIZE_TXT            2003
#define IDS_LABEL_TXT                   2004
#define IDS_CSM_HELP_TXT                2005
#define IDS_UPDATE_SETTINGS_GRP         2006
#define IDS_UPDATE_FREQUENCY_TXT        2007
#define IDS_INCLUDE_BETAS_TXT           2008
#define IDS_NEW_VERSION_AVAIL_TXT       2009
#define IDS_NEW_VERSION_DOWNLOAD_GRP    2010
#define IDS_NEW_VERSION_NOTES_GRP       2011
#define IDS_CHECK_NOW_GRP               2012
#define IDS_TARGET_SYSTEM_TXT           2013
#define IDS_IMAGE_OPTION_TXT            2014
#define IDS_BOOT_SELECTION_TXT          2015
#define IDS_DRIVE_PROPERTIES_TXT        2016
#define IDS_FORMAT_OPTIONS_TXT          2017
#define IDS_STATUS_TXT                  2018
#define MSG_000                         3000
#define MSG_001                         3001
#define MSG_002                         3002
#define MSG_003                         3003
#define MSG_004                         3004
#define MSG_005                         3005
#define MSG_006                         3006
#define MSG_007                         3007
#define MSG_008                         3008
#define MSG_009                         3009
#define MSG_010                         3010
#define MSG_011                         3011
#define MSG_012                         3012
#define MSG_013                         3013
#define MSG_014                         3014
#define MSG_015                         3015
#define MSG_016                         3016
#define MSG_017                         3017
#define MSG_018                         3018
#define MSG_019                         3019
#define MSG_020                         3020
#define MSG_021                         3021
#define MSG_022                         3022
#define MSG_023                         3023
#define MSG_024                         3024
#define MSG_025                         3025
#define MSG_026                         3026
#define MSG_027                         3027
#define MSG_028                         3028
#define MSG_029                         3029
#define MSG_030                         3030
#define MSG_031                         3031
#define MSG_032                         3032
#define MSG_033                         3033
#define MSG_034                         3034
#define MSG_035                         3035
#define MSG_036                         3036
#define MSG_037                         3037
#define MSG_038                         3038
#define MSG_039                         3039
#define MSG_040                         3040
#define MSG_041                         3041
#define MSG_042                         3042
#define MSG_043                         3043
#define MSG_044                         3044
#define MSG_045                         3045
#define MSG_046                         3046
#define MSG_047                         3047
#define MSG_048                         3048
#define MSG_049                         3049
#define MSG_050                         3050
#define MSG_051                         3051
#define MSG_052                         3052
#define MSG_053                         3053
#define MSG_054                         3054
#define MSG_055                         3055
#define MSG_056                         3056
#define MSG_057                         3057
#define MSG_058                         3058
#define MSG_059                         3059
#define MSG_060                         3060
#define MSG_061                         3061
#define MSG_062                         3062
#define MSG_063                         3063
#define MSG_064                         3064
#define MSG_065                         3065
#define MSG_066                         3066
#define MSG_067                         3067
#define MSG_068                         3068
#define MSG_069                         3069
#define MSG_070                         3070
#define MSG_071                         3071
#define MSG_072                         3072
#define MSG_073                         3073
#define MSG_074                         3074
#define MSG_075                         3075
#define MSG_076                         3076
#define MSG_077                         3077
#define MSG_078                         3078
#define MSG_079                         3079
#define MSG_080                         3080
#define MSG_081                         3081
#define MSG_082                         3082
#define MSG_083                         3083
#define MSG_084                         3084
#define MSG_085                         3085
#define MSG_086                         3086
#define MSG_087                         3087
#define MSG_088                         3088
#define MSG_089                         3089
#define MSG_090                         3090
#define MSG_091                         3091
#define MSG_092                         3092
#define MSG_093                         3093
#define MSG_094                         3094
#define MSG_095                         3095
#define MSG_096                         3096
#define MSG_097                         3097
#define MSG_098                         3098
#define MSG_099                         3099
#define MSG_100                         3100
#define MSG_101                         3101
#define MSG_102                         3102
#define MSG_103                         3103
#define MSG_104                         3104
#define MSG_105                         3105
#define MSG_106                         3106
#define MSG_107                         3107
#define MSG_108                         3108
#define MSG_109                         3109
#define MSG_110                         3110
#define MSG_111                         3111
#define MSG_112                         3112
#define MSG_113                         3113
#define MSG_114                         3114
#define MSG_115                         3115
#define MSG_116                         3116
#define MSG_117                         3117
#define MSG_118                         3118
#define MSG_119                         3119
#define MSG_120                         3120
#define MSG_121                         3121
#define MSG_122                         3122
#define MSG_123                         3123
#define MSG_124                         3124
#define MSG_125                         3125
#define MSG_126                         3126
#define MSG_127                         3127
#define MSG_128                         3128
#define MSG_129                         3129
#define MSG_130                         3130
#define MSG_131                         3131
#define MSG_132                         3132
#define MSG_133                         3133
#define MSG_134                         3134
#define MSG_135                         3135
#define MSG_136                         3136
#define MSG_137                         3137
#define MSG_138                         3138
#define MSG_139                         3139
#define MSG_140                         3140
#define MSG_141                         3141
#define MSG_142                         3142
#define MSG_143                         3143
#define MSG_144                         3144
#define MSG_145                         3145
#define MSG_146                         3146
#define MSG_147                         3147
#define MSG_148                         3148
#define MSG_149                         3149
#define MSG_150                         3150
#define MSG_151                         3151
#define MSG_152                         3152
#define MSG_153                         3153
#define MSG_154                         3154
#define MSG_155                         3155
#define MSG_156                         3156
#define MSG_157                         3157
#define MSG_158                         3158
#define MSG_159                         3159
#define MSG_160                         3160
#define MSG_161                         3161
#define MSG_162                         3162
#define MSG_163                         3163
#define MSG_164                         3164
#define MSG_165                         3165
#define MSG_166                         3166
#define MSG_167                         3167
#define MSG_168                         3168
#define MSG_169                         3169
#define MSG_170                         3170
#define MSG_171                         3171
#define MSG_172                         3172
#define MSG_173                         3173
#define MSG_174                         3174
#define MSG_175                         3175
#define MSG_176                         3176
#define MSG_177                         3177
#define MSG_178                         3178
#define MSG_179                         3179
#define MSG_180                         3180
#define MSG_181                         3181
#define MSG_182                         3182
#define MSG_183                         3183
#define MSG_184                         3184
#define MSG_185                         3185
#define MSG_186                         3186
#define MSG_187                         3187
#define MSG_188                         3188
#define MSG_189                         3189
#define MSG_190                         3190
#define MSG_191                         3191
#define MSG_192                         3192
#define MSG_193                         3193
#define MSG_194                         3194
#define MSG_195                         3195
#define MSG_196                         3196
#define MSG_197                         3197
#define MSG_198                         3198
#define MSG_199                         3199
#define MSG_200                         3200
#define MSG_201                         3201
#define MSG_202                         3202
#define MSG_203                         3203
#define MSG_204                         3204
#define MSG_205                         3205
#define MSG_206                         3206
#define MSG_207                         3207
#define MSG_208                         3208
#define MSG_209                         3209
#define MSG_210                         3210
#define MSG_211                         3211
#define MSG_212                         3212
#define MSG_213                         3213
#define MSG_214                         3214
#define MSG_215                         3215
#define MSG_216                         3216
#define MSG_217                         3217
#define MSG_218                         3218
#define MSG_219                         3219
#define MSG_220                         3220
#define MSG_221                         3221
#define MSG_222                         3222
#define MSG_223                         3223
#define MSG_224                         3224
#define MSG_225                         3225
#define MSG_226                         3226
#define MSG_227                         3227
#define MSG_228                         3228
#define MSG_229                         3229
#define MSG_230                         3230
#define MSG_231                         3231
#define MSG_232                         3232
#define MSG_233                         3233
#define MSG_234                         3234
#define MSG_235                         3235
#define MSG_236                         3236
#define MSG_237                         3237
#define MSG_238                         3238
#define MSG_239                         3239
#define MSG_240                         3240
#define MSG_241                         3241
#define MSG_242                         3242
#define MSG_243                         3243
#define MSG_244                         3244
#define MSG_245                         3245
#define MSG_246                         3246
#define MSG_247                         3247
#define MSG_248                         3248
#define MSG_249                         3249
#define MSG_250                         3250
#define MSG_251                         3251
#define MSG_252                         3252
#define MSG_253                         3253
#define MSG_254                         3254
#define MSG_255                         3255
#define MSG_256                         3256
#define MSG_257                         3257
#define MSG_258                         3258
#define MSG_259                         3259
#define MSG_260                         3260
#define MSG_261                         3261
#define MSG_262                         3262
#define MSG_263                         3263
#define MSG_264                         3264
#define MSG_265                         3265
#define MSG_266                         3266
#define MSG_267                         3267
#define MSG_268                         3268
#define MSG_269                         3269
#define MSG_270                         3270
#define MSG_271                         3271
#define MSG_272                         3272
#define MSG_273                         3273
#define MSG_274                         3274
#define MSG_275                         3275
#define MSG_276                         3276
#define MSG_277                         3277
#define MSG_278                         3278
#define MSG_279                         3279
#define MSG_280                         3280
#define MSG_281                         3281
#define MSG_282                         3282
#define MSG_283                         3283
#define MSG_284                         3284
#define MSG_285                         3285
#define MSG_286                         3286
#define MSG_287                         3287
#define MSG_288                         3288
#define MSG_289                         3289
#define MSG_290                         3290
#define MSG_291                         3291
#define MSG_292                         3292
#define MSG_293                         3293
#define MSG_294                         3294
#define MSG_295                         3295
#define MSG_296                         3296
#define MSG_297                         3297
#define MSG_298                         3298
#define MSG_299                         3299
#define MSG_300                         3300
#define MSG_301                         3301
#define MSG_302                         3302
#define MSG_303                         3303
#define MSG_304                         3304
#define MSG_305                         3305
#define MSG_306                         3306
#define MSG_307                         3307
#define MSG_308                         3308
#define MSG_309                         3309
#define MSG_310                         3310
#define MSG_311                         3311
#define MSG_312                         3312
#define MSG_313                         3313
#define MSG_314                         3314
#define MSG_315                         3315
#define MSG_316                         3316
#define MSG_317                         3317
#define MSG_318                         3318
#define MSG_319                         3319
#define MSG_320                         3320
#define MSG_321                         3321
#define MSG_322                         3322
#define MSG_323                         3323
#define MSG_324                         3324
#define MSG_325                         3325
#define MSG_326                         3326
#define MSG_327                         3327
#define MSG_328                         3328
#define MSG_329                         3329
#define MSG_330                         3330
#define MSG_331                         3331
#define MSG_332                         3332
#define MSG_333                         3333
#define MSG_334                         3334
#define MSG_335                         3335
#define MSG_336                         3336
#define MSG_337                         3337
#define MSG_338                         3338
#define MSG_339                         3339
#define MSG_340                         3340
#define MSG_341                         3341
#define MSG_342                         3342
#define MSG_343                         3343
#define MSG_344                         3344
#define MSG_345                         3345
#define MSG_346                         3346
#define MSG_347                         3347
#define MSG_348                         3348
#define MSG_349                         3349
#define MSG_350                         3350
#define MSG_351                         3351
#define MSG_352                         3352
#define MSG_353                         3353
#define MSG_354                         3354
#define MSG_355                         3355
#define MSG_356                         3356
#define MSG_357                         3357
#define MSG_358                         3358
#define MSG_359                         3359
#define MSG_360                         3360
#define MSG_361                         3361
#define MSG_362                         3362
#define MSG_363                         3363
#define MSG_364                         3364
#define MSG_365                         3365
#define MSG_366                         3366
#define MSG_367                         3367
#define MSG_368                         3368
#define MSG_369                         3369
#define MSG_370                         3370
#define MSG_371                         3371
#define MSG_372                         3372
#define MSG_373                         3373
#define MSG_374                         3374
#define MSG_375                         3375
#define MSG_376                         3376
#define MSG_377                         3377
#define MSG_378                         3378
#define MSG_379                         3379
#define MSG_380                         3380
#define MSG_381                         3381
#define MSG_382                         3382
#define MSG_383                         3383
#define MSG_384                         3384
#define MSG_385                         3385
#define MSG_386                         3386
#define MSG_387                         3387
#define MSG_388                         3388
#define MSG_389                         3389
#define MSG_390                         3390
#define MSG_391                         3391
#define MSG_392                         3392
#define MSG_393                         3393
#define MSG_394                         3394
#define MSG_395                         3395
#define MSG_396                         3396
#define MSG_397                         3397
#define MSG_398                         3398
#define MSG_399                         3399
#define MSG_MAX                         3400

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        505
#define _APS_NEXT_COMMAND_VALUE         40001
#define _APS_NEXT_CONTROL_VALUE         1114
#define _APS_NEXT_SYMED_VALUE           4000
#endif
#endif
